from ipywidgets import HBox, Button, Label, IntProgress, Layout
import functools
from abc import ABC, abstractmethod


from lhcsmapi.gui.pc.FgcBrowserAction import FgcBrowserAction
from lhcsmapi.gui.BaseModule import BaseModule


class FgcPmSearchBaseModule(BaseModule, ABC):

    def __init__(self):
        self.find_btn = Button(
            description='Find FGC PM entries',
            tooltip='Click to find FGC PM entries between indicated dates.',
            button_style='',  # 'success', 'info', 'warning', 'danger' or ''
        )
        self.find_btn.on_click(functools.partial(FgcPmSearchBaseModule.handle_find_button_event, self=self))

        # # Text field
        self.lbl_search = Label(value="Click button to search for FGC PM entries within the specified period of time")

        # # Progress bar
        self.progress_search = IntProgress(value=0, min=0, step=1, bar_style='success',
                                           orientation='horizontal', layout=Layout(width='20%', visibility='hidden'))

        self.widget = HBox(children=[self.find_btn, self.lbl_search, self.progress_search])

    def handle_find_button_event(b, self):
        self.mediator.notify(self, FgcBrowserAction.FIND_BUTTON_CLICKED)

    def get_circuit_name(self):
        return self.select_circuit_name_dropdown.value

    @abstractmethod
    def find_fgc_pm_entries_with_qps(self, start_time, end_time, circuit_type, circuit_name):
        pass