import unittest
import warnings
import pandas as pd
import numpy as np
from pathlib import Path
import os
from lhcsmapi.pyedsl.QueryBuilder import QueryBuilder, FeatureProcessing
from lhcsmapi.pyedsl.ResistanceBuilder import ResistanceBuilder
from lhcsmapi.pyedsl.dbquery.DbQueryBuilder import NxcalsDbQueryBuilder
from unittest.mock import patch


def read_csv(file_name):
    path = Path(os.path.dirname(__file__))
    full_path = os.path.join(str(path.parent), 'resources/pyedsl/{}'.format(file_name))
    return pd.read_csv(full_path, index_col=0)

class TestResistanceBuilder(unittest.TestCase):

    def test_resistanceBuilder(self):
        # arrange
        spark = None
        t_start_inj = 1526898157236000000
        t_end_sb = 1526903352338000000
        circuit_type = 'RB'
        plateau_translate_udf = None
        signal_type = 'U_MAG'

        mock_i_meas = read_csv('nxcals_fq/RB_I_MEAS_Debug.csv')
        mock_u_mag = read_csv('nxcals_fq/RB_U_MAG_Debug_No_correction.csv')

        """"
        with patch.object(FeatureProcessing, 'sort_values') as mock_read_i_meas:
            mock_read_i_meas.return_value = mock_i_meas
            # act

            query_i_meas = QueryBuilder().with_nxcals(spark) \
                .with_duration(t_start=int(t_start_inj), t_end=int(t_end_sb)) \
                .with_circuit_type(circuit_type) \
                .with_metadata(circuit_name='*', system='PC', signal='I_MEAS') \
                .feature_query(['mean', 'std'], function=plateau_translate_udf) \
                .sort_values(by='class') \
                .df
        """

        res_busbar_df = ResistanceBuilder().with_busbar_voltage(mock_u_mag) \
            .with_busbar_current(mock_i_meas) \
            .calculate_mean_resistance(circuit_type) \
            .convert_to_row(index=t_start_inj)

        print(res_busbar_df.head())

        # assert
        metadata_ref_i_meas = read_csv('nxcals_fq/RB_I_MEAS_Debug.csv')
        pd.testing.assert_frame_equal(metadata_ref_i_meas, mock_i_meas)


